:github_url: https://github.com/merlinquantum/merlin

.. _user_guide:

==========
User Guide
==========

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents

   layer
   measurement_strategy
   angle_amplitude_encoding
   computation_space
   grouping
   quantum_bridge
   kernels
   feed_forward
   remote_execution
   migration_guide
